@@ -31,7 +31,7 @@ static char file_outfile[FLEN_FILENAME];
 typedef struct    /* structure containing disk file structure */ 
 {
     FILE *fileptr;
-    OFF_T currentpos;
+    LONGLONG currentpos;
     int last_io_op;
 } diskdriver;
 
@@ -91,15 +91,18 @@ int file_open(char *filename, int rwmode, int *handle)
     {
       /* open the original file, with readonly access */
       status = file_openfile(filename, READONLY, &diskfile);
-      if (status)
+      if (status) {
+        file_outfile[0] = '\0';
         return(status);
- 
+      }
+      
       /* create the output file */
       status =  file_create(file_outfile,handle);
       if (status)
       {
         ffpmsg("Unable to create output file for copy of input file:");
         ffpmsg(file_outfile);
+        file_outfile[0] = '\0';
         return(status);
       }
 
@@ -107,8 +110,10 @@ int file_open(char *filename, int rwmode, int *handle)
       while(0 != (nread = fread(recbuf,1,2880, diskfile)))
       {
         status = file_write(*handle, recbuf, nread);
-        if (status)
+        if (status) {
+	   file_outfile[0] = '\0';
            return(status);
+        }
       }
 
       /* close both files */
@@ -119,7 +124,7 @@ int file_open(char *filename, int rwmode, int *handle)
 
       /* reopen the new copy, with correct rwmode */
       status = file_openfile(file_outfile, rwmode, &diskfile);
-
+      file_outfile[0] = '\0';
     }
     else
     {
@@ -340,7 +345,7 @@ int file_create(char *filename, int *handle)
     return(0);
 }
 /*--------------------------------------------------------------------------*/
-int file_truncate(int handle, OFF_T filesize)
+int file_truncate(int handle, LONGLONG filesize)
 /*
   truncate the diskfile to a new smaller size
 */
@@ -350,7 +355,7 @@ int file_truncate(int handle, OFF_T filesize)
     int fdesc;
 
     fdesc = fileno(handleTable[handle].fileptr);
-    ftruncate(fdesc, filesize);
+    ftruncate(fdesc, (OFF_T) filesize);
 
     handleTable[handle].currentpos = filesize;
     handleTable[handle].last_io_op = IO_WRITE;
@@ -360,12 +365,12 @@ int file_truncate(int handle, OFF_T filesize)
     return(0);
 }
 /*--------------------------------------------------------------------------*/
-int file_size(int handle, OFF_T *filesize)
+int file_size(int handle, LONGLONG *filesize)
 /*
   return the size of the file in bytes
 */
 {
-    OFF_T position1;
+    OFF_T position1,position2;
     FILE *diskfile;
 
     diskfile = handleTable[handle].fileptr;
@@ -382,8 +387,8 @@ int file_size(int handle, OFF_T *filesize)
     if (fseeko(diskfile, 0, 2) != 0)  /* seek to end of file */
         return(SEEK_ERROR);
 
-    *filesize = ftello(diskfile);     /* get file size */
-    if (*filesize < 0)
+    position2 = ftello(diskfile);     /* get file size */
+    if (position2 < 0)
         return(SEEK_ERROR);
 
     if (fseeko(diskfile, position1, 0) != 0)  /* seek back to original pos */
@@ -398,8 +403,8 @@ int file_size(int handle, OFF_T *filesize)
     if (fseek(diskfile, 0, 2) != 0)  /* seek to end of file */
         return(SEEK_ERROR);
 
-    *filesize = ftell(diskfile);     /* get file size */
-    if (*filesize < 0)
+    position2 = ftell(diskfile);     /* get file size */
+    if (position2 < 0)
         return(SEEK_ERROR);
 
     if (fseek(diskfile, position1, 0) != 0)  /* seek back to original pos */
@@ -407,6 +412,8 @@ int file_size(int handle, OFF_T *filesize)
 
 #endif
 
+    *filesize = (LONGLONG) position2;
+    
     return(0);
 }
 /*--------------------------------------------------------------------------*/
@@ -455,7 +462,7 @@ int file_flush(int handle)
     return(0);
 }
 /*--------------------------------------------------------------------------*/
-int file_seek(int handle, OFF_T offset)
+int file_seek(int handle, LONGLONG offset)
 /*
   seek to position relative to start of the file
 */
@@ -463,12 +470,12 @@ int file_seek(int handle, OFF_T offset)
 
 #if _FILE_OFFSET_BITS - 0 == 64
 
-    if (fseeko(handleTable[handle].fileptr, offset, 0) != 0)
+    if (fseeko(handleTable[handle].fileptr, (OFF_T) offset, 0) != 0)
         return(SEEK_ERROR);
 
 #else
 
-    if (fseek(handleTable[handle].fileptr, offset, 0) != 0)
+    if (fseek(handleTable[handle].fileptr, (OFF_T) offset, 0) != 0)
         return(SEEK_ERROR);
 
 #endif
@@ -575,6 +582,7 @@ int file_compress_open(char *filename, int rwmode, int *hdl)
           ffpmsg("uncompressed file already exists: (file_compress_open)");
           ffpmsg(file_outfile);
           fclose(outdiskfile);         /* close file and exit with error */
+	  file_outfile[0] = '\0';
           return(FILE_NOT_CREATED); 
         }
     }
@@ -584,6 +592,7 @@ int file_compress_open(char *filename, int rwmode, int *hdl)
     {
         ffpmsg("could not create uncompressed file: (file_compress_open)");
         ffpmsg(file_outfile);
+	file_outfile[0] = '\0';
         return(FILE_NOT_CREATED); 
     }
 
@@ -598,6 +607,7 @@ int file_compress_open(char *filename, int rwmode, int *hdl)
         ffpmsg(filename);
         ffpmsg(" into new output file:");
         ffpmsg(file_outfile);
+	file_outfile[0] = '\0';
         return(status);
     }
 
