@@ -119,9 +119,15 @@
 
    Once the file is closed then the socket is closed.
 
-$Id: drvrnet.c,v 1.56 2000/01/04 11:58:31 oneel Exp $
+$Id: drvrnet.c,v 3.45 2005/12/21 18:18:01 pence Exp $
 
 $Log: drvrnet.c,v $
+Revision 3.45  2005/12/21 18:18:01  pence
+New beta 3.005 release.  Contains new cfortran.h to support integer*8
+parameters when calling cfitsio from Fortran tasks.  Also has modified
+fitsio.h file that now assumes that the 'long long' data type is supported
+by the C compiler (which may not be the case for older compilers).
+
 Revision 1.56  2000/01/04 11:58:31  oneel
 Updates so that compressed network files are dealt with regardless of
 their file names and/or mime types.
@@ -206,7 +212,7 @@ static char netoutfile[MAXLEN];
 typedef struct    /* structure containing disk file structure */ 
 {
   int sock;
-  OFF_T currentpos;
+  LONGLONG currentpos;
 } rootdriver;
 
 static rootdriver handleTable[NMAXFILES];  /* allocate diskfile handle tables */
@@ -2256,7 +2262,7 @@ int root_create(char *filename, int *handle)
     return(0);
 }
 /*--------------------------------------------------------------------------*/
-int root_size(int handle, OFF_T *filesize)
+int root_size(int handle, LONGLONG *filesize)
 /*
   return the size of the file in bytes
 */
@@ -2271,7 +2277,7 @@ int root_size(int handle, OFF_T *filesize)
 
   status = root_send_buffer(sock,ROOTD_STAT,NULL,0);
   status = root_recv_buffer(sock,&op,(char *)&offset, 4);
-  *filesize = (OFF_T) ntohl(offset);
+  *filesize = (LONGLONG) ntohl(offset);
   
   return(0);
 }
@@ -2305,7 +2311,7 @@ int root_flush(int handle)
   return(0);
 }
 /*--------------------------------------------------------------------------*/
-int root_seek(int handle, OFF_T offset)
+int root_seek(int handle, LONGLONG offset)
 /*
   seek to position relative to start of the file
 */
